package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnPlan;

/**
 * 学习计划Service接口
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
public interface ILearnPlanService 
{
    public void updateLearnPlan(Long studentId);
    public LearnPlan getCurrLearnPlan();

    /**
     * 查询学习计划
     * 
     * @param id 学习计划主键
     * @return 学习计划
     */
    public LearnPlan selectLearnPlanById(String id);

    /**
     * 查询学习计划列表
     * 
     * @param learnPlan 学习计划
     * @return 学习计划集合
     */
    public List<LearnPlan> selectLearnPlanList(LearnPlan learnPlan);

    /**
     * 新增学习计划
     * 
     * @param learnPlan 学习计划
     * @return 结果
     */
    public int insertLearnPlan(LearnPlan learnPlan);

    /**
     * 修改学习计划
     * 
     * @param learnPlan 学习计划
     * @return 结果
     */
    public int updateLearnPlan(LearnPlan learnPlan);

    /**
     * 批量删除学习计划
     * 
     * @param ids 需要删除的学习计划主键集合
     * @return 结果
     */
    public int deleteLearnPlanByIds(String[] ids);

    /**
     * 删除学习计划信息
     * 
     * @param id 学习计划主键
     * @return 结果
     */
    public int deleteLearnPlanById(String id);
}
