package com.ruoyi.web.controller.learn;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.learn.domain.LearnPlan;
import com.ruoyi.learn.service.ILearnPlanService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学习计划Controller
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
@RestController
@RequestMapping("/learn/learnPlan")
public class LearnPlanController extends BaseController
{
    @Autowired
    private ILearnPlanService learnPlanService;

    /**
     * 查询学习计划列表
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlan:list')")
    @GetMapping("/list")
    public TableDataInfo list(LearnPlan learnPlan)
    {
        startPage();
        List<LearnPlan> list = learnPlanService.selectLearnPlanList(learnPlan);
        return getDataTable(list);
    }

    /**
     * 导出学习计划列表
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlan:export')")
    @Log(title = "学习计划", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LearnPlan learnPlan)
    {
        List<LearnPlan> list = learnPlanService.selectLearnPlanList(learnPlan);
        ExcelUtil<LearnPlan> util = new ExcelUtil<LearnPlan>(LearnPlan.class);
        util.exportExcel(response, list, "学习计划数据");
    }

    /**
     * 获取学习计划详细信息
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(learnPlanService.selectLearnPlanById(id));
    }

    /**
     * 新增学习计划
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlan:add')")
    @Log(title = "学习计划", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LearnPlan learnPlan)
    {
        return toAjax(learnPlanService.insertLearnPlan(learnPlan));
    }

    /**
     * 修改学习计划
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlan:edit')")
    @Log(title = "学习计划", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LearnPlan learnPlan)
    {
        return toAjax(learnPlanService.updateLearnPlan(learnPlan));
    }

    /**
     * 删除学习计划
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlan:remove')")
    @Log(title = "学习计划", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(learnPlanService.deleteLearnPlanByIds(ids));
    }
}
